<?php

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2013 Thomas Deuling <typo3@coding.ms>, coding.ms
 *  
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 *
 *
 * @package ftm
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 *
 */
class Tx_Ftm_Domain_Model_Template extends Tx_Extbase_DomainObject_AbstractEntity {

    /**
     * Directory within fileadmin
     *
     * @var string
     * @validate NotEmpty
     * @since 1.0.0
     */
    protected $fileadminDir;

    /**
     * MD5-Hash of the setup.ts
     *
     * @var string
     * @since 1.0.0
     */
    protected $md5HashSetupTs;

    /**
     * MD5-Hash of the constants.ts
     *
     * @var string
     * @since 1.0.0
     */
    protected $md5HashConstantsTs;

    /**
     * MD5-Hash of the Template-Data
     *
     * @var string
     * @since 1.0.0
     */
    protected $md5HashTemplateData;

    /**
     * Warnungen gelesen!?
     *
     * @var boolean
     * @since 1.0.0
     */
    protected $disclaimerAccepted;

    /**
     * config
     *
     * @var Tx_Ftm_Domain_Model_TemplateConfig
     * @since 1.0.0
     */
    protected $config;

    /**
     * meta
     *
     * @var Tx_Ftm_Domain_Model_TemplateMeta
     * @since 1.0.0
     */
    protected $meta;

    /**
     * Website-Sprachen
     *
     * @var Tx_Extbase_Persistence_ObjectStorage<Tx_Ftm_Domain_Model_TemplateLanguage>
     * @since 1.0.0
     */
    protected $language;

    /**
     * Fluid-Templates
     *
     * @var Tx_Extbase_Persistence_ObjectStorage<Tx_Ftm_Domain_Model_TemplateFluid>
     * @lazy
     * @since 1.0.0
     */
    protected $fluid;

    /**
     * Less-Variables
     *
     * @var Tx_Extbase_Persistence_ObjectStorage<Tx_Ftm_Domain_Model_TemplateLessVariable>
     * @since 1.0.0
     */
    protected $lessVariable;

    /**
     * Menu-Container
     *
     * @var Tx_Extbase_Persistence_ObjectStorage<Tx_Ftm_Domain_Model_TemplateMenuContainer>
     * @since 1.0.0
     */
    protected $menuContainer;

    /**
     * Marker
     *
     * @var Tx_Extbase_Persistence_ObjectStorage<Tx_Ftm_Domain_Model_TemplateMarker>
     * @since 1.0.0
     */
    protected $marker;

    /**
     * Marker
     *
     * @var Tx_Extbase_Persistence_ObjectStorage<Tx_Ftm_Domain_Model_TemplateExt>
     * @since 1.0.0
     */
    protected $extensions;

    /**
     * __construct
     *
     * @return void
     * @since 1.0.0
     */
    public function __construct() {
        //Do not remove the next line: It would break the functionality
        $this->initStorageObjects();
    }

    /**
     * Initializes all Tx_Extbase_Persistence_ObjectStorage properties.
     *
     * @return void
     * @since 1.0.0
     */
    protected function initStorageObjects() {
        /**
         * Do not modify this method!
         * It will be rewritten on each save in the extension builder
         * You may modify the constructor of this class instead
         */
        $this->language      = new Tx_Extbase_Persistence_ObjectStorage();
        $this->fluid         = new Tx_Extbase_Persistence_ObjectStorage();
        $this->lessVariable  = new Tx_Extbase_Persistence_ObjectStorage();
        $this->menuContainer = new Tx_Extbase_Persistence_ObjectStorage();
        $this->marker        = new Tx_Extbase_Persistence_ObjectStorage();
        $this->extensions    = new Tx_Extbase_Persistence_ObjectStorage();
    }

    /**
     * Returns the fileadminDir
     *
     * @return string $fileadminDir
     * @since 1.0.0
     */
    public function getFileadminDir() {
        return $this->fileadminDir;
    }

    /**
     * Sets the fileadminDir
     *
     * @param string $fileadminDir
     * @return void
     * @since 1.0.0
     */
    public function setFileadminDir($fileadminDir) {
        $this->fileadminDir = $fileadminDir;
    }

    /**
     * Returns the md5HashSetupTs
     *
     * @return string $md5HashSetupTs
     * @since 1.0.0
     */
    public function getMd5HashSetupTs() {
        return $this->md5HashSetupTs;
    }

    /**
     * Sets the md5HashSetupTs
     *
     * @param string $md5HashSetupTs
     * @return void
     * @since 1.0.0
     */
    public function setMd5HashSetupTs($md5HashSetupTs) {
        $this->md5HashSetupTs = $md5HashSetupTs;
    }

    /**
     * Returns the md5HashConstantsTs
     *
     * @return string $md5HashConstantsTs
     * @since 1.0.0
     */
    public function getMd5HashConstantsTs() {
        return $this->md5HashConstantsTs;
    }

    /**
     * Sets the md5HashConstantsTs
     *
     * @param string $md5HashConstantsTs
     * @return void
     * @since 1.0.0
     */
    public function setMd5HashConstantsTs($md5HashConstantsTs) {
        $this->md5HashConstantsTs = $md5HashConstantsTs;
    }

    /**
     * Returns the md5HashTemplateData
     *
     * @return string $md5HashTemplateData
     * @since 1.0.0
     */
    public function getMd5HashTemplateData() {
        return $this->md5HashTemplateData;
    }

    /**
     * Sets the md5HashTemplateData
     *
     * @param string $md5HashTemplateData
     * @return void
     * @since 1.0.0
     */
    public function setMd5HashTemplateData($md5HashTemplateData) {
        $this->md5HashTemplateData = $md5HashTemplateData;
    }

    /**
     * Returns the disclaimerAccepted
     *
     * @return boolean $disclaimerAccepted
     * @since 1.0.0
     */
    public function getDisclaimerAccepted() {
        return $this->disclaimerAccepted;
    }

    /**
     * Sets the disclaimerAccepted
     *
     * @param boolean $disclaimerAccepted
     * @return void
     * @since 1.0.0
     */
    public function setDisclaimerAccepted($disclaimerAccepted) {
        $this->disclaimerAccepted = $disclaimerAccepted;
    }

    /**
     * Returns the boolean state of clear
     *
     * @return boolean
     * @since 1.0.0
     */
    public function isDisclaimerAccepted() {
        return $this->getDisclaimerAccepted();
    }

    /**
     * Returns the config
     *
     * @return Tx_Ftm_Domain_Model_TemplateConfig $config
     * @since 1.0.0
     */
    public function getConfig() {
        return $this->config;
    }

    /**
     * Sets the config
     *
     * @param Tx_Ftm_Domain_Model_TemplateConfig $config
     * @return void
     * @since 1.0.0
     */
    public function setConfig(Tx_Ftm_Domain_Model_TemplateConfig $config) {
        $this->config = $config;
    }

    /**
     * Returns the meta
     *
     * @return Tx_Ftm_Domain_Model_TemplateMeta $meta
     * @since 1.0.0
     */
    public function getMeta() {
        return $this->meta;
    }

    /**
     * Sets the meta
     *
     * @param Tx_Ftm_Domain_Model_TemplateMeta $meta
     * @return void
     * @since 1.0.0
     */
    public function setMeta(Tx_Ftm_Domain_Model_TemplateMeta $meta) {
        $this->meta = $meta;
    }

    /**
     * Adds a TemplateLessVariable
     *
     * @param Tx_Ftm_Domain_Model_TemplateLessVariable $lessVariable
     * @return void
     * @since 1.0.0
     */
    public function addLessVariable(Tx_Ftm_Domain_Model_TemplateLessVariable $lessVariable) {
        $this->lessVariable->attach($lessVariable);
    }

    /**
     * Removes a TemplateLessVariable
     *
     * @param Tx_Ftm_Domain_Model_TemplateLessVariable $lessVariableToRemove The TemplateLessVariable to be removed
     * @return void
     * @since 1.0.0
     */
    public function removeLessVariable(Tx_Ftm_Domain_Model_TemplateLessVariable $lessVariableToRemove) {
        $this->lessVariable->detach($lessVariableToRemove);
    }

    /**
     * Returns the lessVariable
     *
     * @return Tx_Extbase_Persistence_ObjectStorage<Tx_Ftm_Domain_Model_TemplateLessVariable> $lessVariable
     * @since 1.0.0
     */
    public function getLessVariable() {
        return $this->lessVariable;
    }

    /**
     * Sets the lessVariable
     *
     * @param Tx_Extbase_Persistence_ObjectStorage<Tx_Ftm_Domain_Model_TemplateLessVariable> $lessVariable
     * @return void
     * @since 1.0.0
     */
    public function setLessVariable(Tx_Extbase_Persistence_ObjectStorage $lessVariable) {
        $this->lessVariable = $lessVariable;
    }

    /**
     * Adds a TemplateLanguage
     *
     * @param Tx_Ftm_Domain_Model_TemplateLanguage $language
     * @return void
     * @since 1.0.0
     */
    public function addLanguage(Tx_Ftm_Domain_Model_TemplateLanguage $language) {
        $this->language->attach($language);
    }

    /**
     * Removes a TemplateLanguage
     *
     * @param Tx_Ftm_Domain_Model_TemplateLanguage $languageToRemove The TemplateLanguage to be removed
     * @return void
     * @since 1.0.0
     */
    public function removeLanguage(Tx_Ftm_Domain_Model_TemplateLanguage $languageToRemove) {
        $this->language->detach($languageToRemove);
    }

    /**
     * Returns the language
     *
     * @return Tx_Extbase_Persistence_ObjectStorage<Tx_Ftm_Domain_Model_TemplateLanguage> $language
     * @since 1.0.0
     */
    public function getLanguage() {
        return $this->language;
    }

    /**
     * Sets the language
     *
     * @param Tx_Extbase_Persistence_ObjectStorage<Tx_Ftm_Domain_Model_TemplateLanguage> $language
     * @return void
     * @since 1.0.0
     */
    public function setLanguage(Tx_Extbase_Persistence_ObjectStorage $language) {
        $this->language = $language;
    
    }

    /**
     * Adds a TemplateFluid
     *
     * @param Tx_Ftm_Domain_Model_TemplateFluid $fluid
     * @return void
     * @since 1.0.0
     */
    public function addFluid(Tx_Ftm_Domain_Model_TemplateFluid $fluid) {
        $this->fluid->attach($fluid);
    }

    /**
     * Removes a TemplateFluid
     *
     * @param Tx_Ftm_Domain_Model_TemplateFluid $fluidToRemove The TemplateFluid to be removed
     * @return void
     * @since 1.0.0
     */
    public function removeFluid(Tx_Ftm_Domain_Model_TemplateFluid $fluidToRemove) {
        $this->fluid->detach($fluidToRemove);
    }

    /**
     * Returns the fluid
     *
     * @return Tx_Extbase_Persistence_ObjectStorage<Tx_Ftm_Domain_Model_TemplateFluid> $fluid
     * @since 1.0.0
     */
    public function getFluid() {
        return $this->fluid;
    }

    /**
     * Sets the fluid
     *
     * @param Tx_Extbase_Persistence_ObjectStorage<Tx_Ftm_Domain_Model_TemplateFluid> $fluid
     * @return void
     * @since 1.0.0
     */
    public function setFluid(Tx_Extbase_Persistence_ObjectStorage $fluid) {
        $this->fluid = $fluid;
    }

    /**
     * Adds a TemplateMenuContainer
     *
     * @param Tx_Ftm_Domain_Model_TemplateMenuContainer $menuContainer
     * @return void
     * @since 1.0.0
     */
    public function addMenuContainer(Tx_Ftm_Domain_Model_TemplateMenuContainer $menuContainer) {
        $this->menuContainer->attach($menuContainer);
    }

    /**
     * Removes a TemplateMenuContainer
     *
     * @param Tx_Ftm_Domain_Model_TemplateMenuContainer $menuContainerToRemove The TemplateMenuContainer to be removed
     * @return void
     * @since 1.0.0
     */
    public function removeMenuContainer(Tx_Ftm_Domain_Model_TemplateMenuContainer $menuContainerToRemove) {
        $this->menuContainer->detach($menuContainerToRemove);
    }

    /**
     * Returns the menuContainer
     *
     * @return Tx_Extbase_Persistence_ObjectStorage<Tx_Ftm_Domain_Model_TemplateMenuContainer> $menuContainer
     * @since 1.0.0
     */
    public function getMenuContainer() {
        return $this->menuContainer;
    }

    /**
     * Sets the menuContainer
     *
     * @param Tx_Extbase_Persistence_ObjectStorage<Tx_Ftm_Domain_Model_TemplateMenuContainer> $menuContainer
     * @return void
     * @since 1.0.0
     */
    public function setMenuContainer(Tx_Extbase_Persistence_ObjectStorage $menuContainer) {
        $this->menuContainer = $menuContainer;
    }

    /**
     * Adds a TemplateMarker
     *
     * @param Tx_Ftm_Domain_Model_TemplateMarker $marker
     * @return void
     * @since 1.0.0
     */
    public function addMarker(Tx_Ftm_Domain_Model_TemplateMarker $marker) {
        $this->marker->attach($marker);
    }

    /**
     * Removes a TemplateMarker
     *
     * @param Tx_Ftm_Domain_Model_TemplateMarker $markerToRemove The TemplateMarker to be removed
     * @return void
     * @since 1.0.0
     */
    public function removeMarker(Tx_Ftm_Domain_Model_TemplateMarker $markerToRemove) {
        $this->marker->detach($markerToRemove);
    }

    /**
     * Returns the marker
     *
     * @return Tx_Extbase_Persistence_ObjectStorage<Tx_Ftm_Domain_Model_TemplateMarker> $marker
     * @since 1.0.0
     */
    public function getMarker() {
        return $this->marker;
    }

    /**
     * Sets the marker
     *
     * @param Tx_Extbase_Persistence_ObjectStorage<Tx_Ftm_Domain_Model_TemplateMarker> $marker
     * @return void
     * @since 1.0.0
     */
    public function setMarker(Tx_Extbase_Persistence_ObjectStorage $marker) {
        $this->marker = $marker;
    }

    /**
     * Adds a TemplateExt
     *
     * @param Tx_Ftm_Domain_Model_TemplateExt $extension
     * @return void
     * @since 1.0.0
     */
    public function addExtension(Tx_Ftm_Domain_Model_TemplateExt $extension) {
        $this->extensions->attach($extension);
    }

    /**
     * Removes a TemplateExt
     *
     * @param Tx_Ftm_Domain_Model_TemplateExt $extensionToRemove The TemplateExt to be removed
     * @return void
     * @since 1.0.0
     */
    public function removeExtension(Tx_Ftm_Domain_Model_TemplateExt $extensionToRemove) {
        $this->extensions->detach($extensionToRemove);
    }

    /**
     * Returns the extensions
     *
     * @param string $extName Name of the extensions
     * @return Tx_Extbase_Persistence_ObjectStorage<Tx_Ftm_Domain_Model_TemplateExt> $extensions
     * @since 1.0.0
     */
    public function getExtensionByName($extName) {
        $ext = null;
        if($this->extensions->count()>0) {
            foreach($this->extensions as $extension) {
                if($extension->getExtKey()==$extName) {
                    return $extension;
                }
            }
        }
        return $ext;
    }

    /**
     * Returns the extensions
     *
     * @return Tx_Extbase_Persistence_ObjectStorage<Tx_Ftm_Domain_Model_TemplateExt> $extensions
     * @since 1.0.0
     */
    public function getExtensions() {
        return $this->extensions;
    }

    /**
     * Sets the extensions
     *
     * @param Tx_Extbase_Persistence_ObjectStorage<Tx_Ftm_Domain_Model_TemplateExt> $extensions
     * @return void
     * @since 1.0.0
     */
    public function setExtensions(Tx_Extbase_Persistence_ObjectStorage $extensions) {
        $this->extensions = $extensions;
    }

    /**
     * Returns the data as array
     * @return array
     * @since 1.0.0
     */
    public function toArray() {
        
        // Achtung: 
        // PluginService mag nur ein-dimensionale Arrays!
        
        $data = array();
        $data['fileadminDir'] = $this->getFileadminDir();
        
        
        // Meta und Config ohne Schleife
        // weil diese immer nur einmal existieren
        $data['config']       = serialize($this->config->toArray());
        $data['meta']         = serialize($this->meta->toArray());
        
        
        // Language
        // ------------------------------
        $tempLanguageArray = array();
        $defaultLanguage   = array();
        $defaultLanguage['languageUid'] = $this->config->getLanguageUid();
        $defaultLanguage['title']       = $this->config->getLanguageTitle();
        $defaultLanguage['language']    = $this->config->getLanguage();
        $defaultLanguage['localeAll']   = $this->config->getLocaleAll();
        $tempLanguageArray[0] = $defaultLanguage;
        if(!empty($this->language)) {
            foreach($this->language as $tempLanguage) {
                $tempLanguageArray[$tempLanguage->getLanguageUid()] = $tempLanguage->toArray();
            }
        }
        $data['language'] = serialize($tempLanguageArray);
        
        
        // Less-Variablen
        // ------------------------------
        $tempLessVariableArray = array();
        if(!empty($this->lessVariable)) {
            foreach($this->lessVariable as $tempLessVariable) {
                $tempLessVariableArray[] = $tempLessVariable->toArray();
            }
        }
        $data['lessVariable'] = serialize($tempLessVariableArray);
        
        
        // Fluid-Template-Daten
        // ------------------------------
        $tempFluidArray = array();
        if(!empty($this->fluid)) {
            foreach($this->fluid as $tempFluid) {
                $tempFluidArray[$tempFluid->getTemplateType()][] = $tempFluid->toArray();
            }
        }
        $data['fluid'] = serialize($tempFluidArray);
        
        
        // Marker-Daten
        // ------------------------------
        $tempMarkerArray = array();
        if(!empty($this->marker)) {
            foreach($this->marker as $tempMarker) {
                $tempMarkerArray[$tempMarker->getMarkerName()] = $tempMarker->toArray();
            }
        }
        $data['marker'] = serialize($tempMarkerArray);
        
        
        // Menu-Daten
        // ------------------------------
        $tempMenuArray = array();
        if(!empty($this->menuContainer)) {
            foreach($this->menuContainer as $tempMenu) {
                $tempMenuArray[$tempMenu->getMenuName()] = $tempMenu->toArray();
            }
        }
        $data['menu'] = serialize($tempMenuArray);
        
        
        // Extension-Daten
        // ------------------------------
        $tempExtensionArray = array();
        if(!empty($this->extensions)) {
            foreach($this->extensions as $tempExtension) {
                $tempExtensionArray[$tempExtension->getExtKey()] = $tempExtension->toArray();
            }
        }
        $data['extensions'] = serialize($tempExtensionArray);
        
        
        return $data;
    }

}
?>