<?php
/***************************************************************
 *  Copyright notice
 *
 *  (c) 2012 Thomas Deuling <typo3@coding.ms>, coding.ms
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * Fluid Funktionen
 * Sorgt z.B. dafuer, das die Template-Dateien, die nur
 * als Datei existieren als Datensatz erstellen werden
 *
 * @package ftm
 * @subpackage Service
 * 
 * @author Thomas Deuling <typo3@coding.ms>
 * @since 1.0.0
 */
class Tx_Ftm_Service_Fluid {

    /**
     * Object-Manager
     *
     * @var Tx_Extbase_Object_ObjectManager
     */
    protected $objectManager;

    /**
     * Template Repository
     *
     * @var Tx_Ftm_Domain_Repository_TemplateRepository
     */
    protected $templateRepository;

    /**
     * Persistence-manager
     *
     * @var Tx_Extbase_Persistence_Manager
     */
    protected $persistenceManager;

    /**
     * injectTemplateRepository
     *
     * @param Tx_Ftm_Domain_Repository_TemplateRepository $templateRepository
     * @return void
     */
    public function injectTemplateRepository(Tx_Ftm_Domain_Repository_TemplateRepository $templateRepository) {
        $this->templateRepository = $templateRepository;
    }

    /**
     * injectPersistenceManager
     *
     * @param Tx_Extbase_Persistence_Manager $persistenceManager
     * @return void
     */
    public function injectPersistenceManager(Tx_Extbase_Persistence_Manager $persistenceManager) {
        $this->persistenceManager = $persistenceManager;
    }

    /**
     * injectObjectManager
     *
     * @param Tx_Extbase_Object_ObjectManager $objectManager
     * @return void
     */
    public function injectObjectManager(Tx_Extbase_Object_ObjectManager $objectManager) {
        $this->objectManager = $objectManager;
    }
         
    /**
     * Prueft die Templates eines Types
     * 
     * @author Thomas Deuling <typo3@coding.ms>
     * @param  Tx_Ftm_Domain_Model_Template $fluidTemplate
     * @param  string $fluidType partial/layout/template
     * @return mixed true wenn alle Dateien vorhanden sind, ansonsten ein Array mit den vermissten Dateien
     * @since  1.0.0
     */
    public function checkFiles(Tx_Ftm_Domain_Model_Template $fluidTemplate, $fluidType='template') {
        
        $success = true;
        $missingFiles = array();
        
        
        // Zuerst pruefen ob es das Template-Verzeichnis gibt
        $relPath = "fileadmin/".$fluidTemplate->getFileadminDir()."/template/fluid/".$fluidType."s/";
        $absPath = t3lib_div::getFileAbsFileName($relPath);
        if(is_dir($absPath)) {
            
            
            // Erst alle Dateien holen
            $filesLocal = array();
            if($handle=opendir($absPath)) {
                while($file=readdir($handle)){
                    if(substr($file , 0, 1) != ".") {
                        $filesLocal[] = $file;
                    }
                }
            }
            
            
            // Dann alle bekannten herausloeschen
            $filesDb = array();
            $fluidFiles = $fluidTemplate->getFluid();
            if(!empty($fluidFiles)) {
                foreach($fluidFiles as $fluidFile) {
                    if($fluidFile->getTemplateType()==$fluidType) {
                        $filesDb[] = $fluidFile->getTemplateFile().'.html';
                    }
                }
            }
            
            
            // Ermittelten Werte vergleichen
            $missingFiles = array_diff($filesLocal, $filesDb);
            
        }
        else {
            $success = false;
            throw new Exception("Template dir '".$absPath."' not found", 1);
        }
        
        
        // Antword generieren
        if(empty($missingFiles)) {
            return true;
        }
        else {
            return $missingFiles;
        }
    }
    
    public function createFiles(Tx_Ftm_Domain_Model_Template $fluidTemplate, $fluidType='template', array $fluidFiles=array()) {
        
        $messages = "";
        
        // Wenn Dateien uebergeben wurden
        if(!empty($fluidFiles)) {
            foreach($fluidFiles as $fluidFile) {
                
                $tempCode = "";
                
                // Zuerst pruefen ob es das Template-Verzeichnis gibt
                $relPath = "fileadmin/".$fluidTemplate->getFileadminDir()."/template/fluid/".$fluidType."s/";
                $absPath = t3lib_div::getFileAbsFileName($relPath);
                if(is_dir($absPath)) {
                    if(file_exists($absPath.$fluidFile)) {
                     
                        // Lese den Code aus
                        $tempCode = file_get_contents($absPath.$fluidFile);
                    }
                    else {
                        throw new Exception("Template file '".$fluidFile."' not found", 1);
                    }
                }
                else {
                    throw new Exception("Template dir '".$absPath."' not found", 1);
                }
                        
                
                
                /**
                 * @var Tx_Ftm_Domain_Model_TemplateFluid
                 */
                $tempFluid = $this->objectManager->create('Tx_Ftm_Domain_Model_TemplateFluid');
                $tempName = str_replace('.html', '', $fluidFile);
                $tempFluid->setTemplateFile($tempName);
                $tempFluid->setTemplateType($fluidType);
                $tempFluid->setTemplateCode($tempCode);
                $tempFluid->setTemplateTitle($tempName." - ".$fluidType);
                $tempFluid->setPid($fluidTemplate->getPid());
                $fluidTemplate->addFluid($tempFluid);
                
                $messages.= $fluidFile." Fluid ".ucfirst($fluidType)." erstellt<br />\n";
                
            }
         
         
            // Aenderungen speichern
            $this->templateRepository->update($fluidTemplate);
                      
            // und persistieren
            $this->persistenceManager->persistAll();
        }
        
        return $messages;        
    }
   
    
}

?>