<?php
/***************************************************************
 *  Copyright notice
 *
 *  (c) 2012 Thomas Deuling <typo3@coding.ms>, coding.ms
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * Managed alle Aktionen mit den Seiten/Pages
 *
 * @package ftm
 * @subpackage Service
 */
class Tx_Ftm_Service_Pages {

    /**
     * Benoetigte globale Seiten-Struktur
     * @var array
     * @since 1.0.0
     */
    protected $globalPages = array(
        'GlobalStorage'                => array('doktype'=>'254', 'module'=>''), //Hier liegen alle globalen Datensaetze',
        'GlobalStorage/BackendLayouts' => array('doktype'=>'254', 'module'=>''), //Hier liegen alle Backend-Layouts',
        'GlobalStorage/GridLayouts'    => array('doktype'=>'254', 'module'=>''), //Hier liegen alle Grid-Layouts',
    );

    /**
     * Benoetigte domain Seiten-Struktur
     * @var array
     * @since 1.0.0
     */
    protected $domainPages = array(
        'DomainStorage'                 => array('doktype'=>'254', 'module'=>''), //Hier liegen alle globalen Datensaetze',
        'DomainStorage/BackendLayouts'  => array('doktype'=>'254', 'module'=>''), //Hier liegen alle Backend-Layouts',
        'DomainStorage/ContentElements' => array('doktype'=>'254', 'module'=>''), //Hier liegen alle Content-Elemente',
        'DomainStorage/FrontendUser'    => array('doktype'=>'254', 'module'=>'fe_users'), //Hier liegen alle Frontend-User',
    );

    /**
     * Pages Repository
     *
     * @var Tx_Ftm_Domain_Repository_PagesRepository
     */
    protected $pagesRepository;

    /**
     * Persistence-manager
     *
     * @var Tx_Extbase_Persistence_Manager
     */
    protected $persistenceManager;

    /**
     * Object-Manager
     *
     * @var Tx_Extbase_Object_ObjectManager
     */
    protected $objectManager;

    /**
     * Meldungen
     *
     * @var string
     */
    protected $messages = "";

    /**
     * injectPagesRepository
     *
     * @param Tx_Ftm_Domain_Repository_PagesRepository $pagesRepository
     * @return void
     */
    public function injectPagesRepository(Tx_Ftm_Domain_Repository_PagesRepository $pagesRepository) {
        $this->pagesRepository = $pagesRepository;
    }

    /**
     * injectPersistenceManager
     *
     * @param Tx_Extbase_Persistence_Manager $persistenceManager
     * @return void
     */
    public function injectPersistenceManager(Tx_Extbase_Persistence_Manager $persistenceManager) {
        $this->persistenceManager = $persistenceManager;
    }

    /**
     * injectObjectManager
     *
     * @param Tx_Extbase_Object_ObjectManager $objectManager
     * @return void
     */
    public function injectObjectManager(Tx_Extbase_Object_ObjectManager $objectManager) {
        $this->objectManager = $objectManager;
    }
    
    /**
     * Prueft ob alle globalen Seiten vorhanden sind
     *
     * @author     Thomas Deuling <typo3@coding.ms>
     * @since      22.11.2013
     * 
     * @param integer $ftmPid Page-Id des FTM-Templates
     * @return mixed boolean wenn alles aktuell ist, ansonsten die Meldungens
     */
    public function checkPages($ftmPid=0) {
        
        
        // GlobalStorage
        // Wir starten immer bei Tiefe: 0
        // -------------------------------------------------
        $currentPid = 0;
        $currentPagePath = "";
        
        if(!empty($this->globalPages)) {
            foreach ($this->globalPages as $title => $config) {
                
                /**
                 * @var Tx_Ftm_Domain_Model_Pages
                 */
                $currentPage = $this->getAndCreatePage($currentPagePath, $title, $currentPid, $config);
                if($currentPid==0) {
                    $currentPid  = $currentPage->getUid();
                    $currentPagePath = $currentPage->getTitle()."/";
                }
                
            }
        }
        // -------------------------------------------------
        
        
        // DomainStorage
        // Wir starten immer bei Tiefe: x -> FTM-Seite
        // -------------------------------------------------
        $currentPid = $ftmPid;
        $currentPagePath = "";
        
        if(!empty($this->domainPages)) {
            foreach ($this->domainPages as $title => $config) {
                
                /**
                 * @var Tx_Ftm_Domain_Model_Pages
                 */
                $currentPage = $this->getAndCreatePage($currentPagePath, $title, $currentPid, $config);
                if($currentPid==$ftmPid) {
                    $currentPid  = $currentPage->getUid();
                    $currentPagePath = $currentPage->getTitle()."/";
                }
                
            }
        }
        // -------------------------------------------------
        
        
        // Wenn Seiten erstellt worden sind
        // aktualisiere den Page-Tree
        if(trim($this->messages)!="") {
            t3lib_BEfunc::setUpdateSignal('updatePageTree');
            return $this->messages;
        }
        else {
            return true;
        }
    }
        
    /**
     * Seite auslesen und ggf. erstellen
     * 
     * @param string $title Name der Seite
     * @param integer $pid Pid der Eltern-Seite der Seite
     * @param integer $doktype Typ der Seite, bspw. 254 fuer Container
     * @return Tx_Ftm_Domain_Model_Pages Existierende oder neue Seite
     */
    protected function getAndCreatePage($currentPagePath, $fullTitle, $pid, $config) {
        
        $title = str_replace($currentPagePath, "", $fullTitle);
                
        $rootPage = $this->pagesRepository->findOneByTitleAndPid($title, $pid);
        if(!($rootPage instanceof Tx_Ftm_Domain_Model_Pages)) {
            
            /**
             * @var Tx_Ftm_Domain_Model_Pages
             */
            $rootPage = $this->objectManager->create('Tx_Ftm_Domain_Model_Pages');
            $rootPage->setPid($pid);
            $rootPage->setTitle($title);
            $rootPage->setDoktype($config['doktype']);
            $rootPage->setModule($config['module']);
            
            // Seite speichern
            $this->pagesRepository->add($rootPage);
                      
            // und persistieren
            $this->persistenceManager->persistAll();
            
            // Meldung registrieren
            $this->messages.= $fullTitle." wurde erstellt<br />\n";
        }
                    
        return $rootPage;
    } 
    
}

?>
