<?php
/***************************************************************
 *  Copyright notice
 *
 *  (c) 2012 Thomas Deuling <typo3@coding.ms>, coding.ms
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * Managed alle Aktionen mit dem Sys-Template
 *
 * @package ftm
 * @subpackage Service
 */
class Tx_Ftm_Service_SysTemplate {

    /**
     * Sys-Template Repository
     *
     * @var Tx_Ftm_Domain_Repository_SysTemplateRepository
     */
    protected $sysTemplateRepository;

    /**
     * Persistence-manager
     *
     * @var Tx_Extbase_Persistence_Manager
     */
    protected $persistenceManager;

    /**
     * injectSysTemplateRepository
     *
     * @param Tx_Ftm_Domain_Repository_SysTemplateRepository $sysTemplateRepository
     * @return void
     */
    public function injectSysTemplateRepository(Tx_Ftm_Domain_Repository_SysTemplateRepository $sysTemplateRepository) {
        $this->sysTemplateRepository = $sysTemplateRepository;
    }

    /**
     * injectPersistenceManager
     *
     * @param Tx_Extbase_Persistence_Manager $persistenceManager
     * @return void
     */
    public function injectPersistenceManager(Tx_Extbase_Persistence_Manager $persistenceManager) {
        $this->persistenceManager = $persistenceManager;
    }
    
    /**
     * Prueft ob das Sys-Template vorhanden ist, und
     * generiert es ggf. neu
     * Dies machen wir ohne Repository, weil wir noch nicht
     * mappen koennen.
     *
     * @author     Thomas Deuling <typo3@coding.ms>
     * @param      integer $pid Page-ID des Templates
     * @since      22.11.2013
     */
    public function checkSysTemplate($pid) {
        
        
        /**
         * @ToDo: Hier muss auch geprueft werden ob ein fremdes Root-Template auf dieser Seite liegt!
         */
        
        // Template auslesen
        $result = $GLOBALS['TYPO3_DB']->exec_SELECTquery(
            '*',
            'sys_template',
            'pid='.((int)$pid).' AND root=1 AND deleted=0',
            '',
            ''
        );
               
        
        // Template in Result!?
        $found = false;
        $foundVersion = "";
        if($result) {
            
            // Alle gefundenen Template pruefen
            while ($row = mysql_fetch_assoc($result)) {

                // Schauen ob es ein FTM Sys-Template ist
                $titleParts = explode(" - ", $row["title"]);
                
                
                if(!empty($titleParts)) {
                    if(substr($titleParts[0], 0, 3)=='FTM') {
                        
                        // Merken das es ein FTM Sys-Template ist
                        // aber nur wenn noch keins gefunden wurde
                        if(!$found) {
                            $found = true;
                            $foundRow = $row;
                            $foundVersion = trim(str_replace("FTM", "", $titleParts[0]));
                            
                        }
                        else {
                            return "error";
                        }
                        
                    }                
                }
                else {
                    return "error";
                }

            }
        }
        

        // Es gibt noch kein Template
        if(!$found) {
                
            // Erstellen wir eins
            $sysTemplateData = array();
            $sysTemplateData['pid']   = (int)$pid;
            $sysTemplateData['root']  = 1;
            $sysTemplateData['clear'] = 3;
            $sysTemplateData['title'] = 'FTM '.FTM_VERSION.' - Root-Template (Dont change this name!)';
            
            $includeStatics = array();
            $includeStatics[] = "EXT:css_styled_content/static/";
            $includeStatics[] = "EXT:ftm/Configuration/TypoScript";
            $includeStatics[] = "EXT:static_info_tables/static/static_info_tables/";
            $includeStatics[] = "EXT:t3_less/Configuration/TypoScript";
            $includeStatics[] = "EXT:gridelements/static/gridelements/";
            
            $sysTemplateData['include_static_file'] = implode(',', $includeStatics);
                                
            $res = $GLOBALS['TYPO3_DB']->exec_INSERTquery('sys_template', $sysTemplateData);
                        
            return "created";
        }

        // Template muss aktualisiert werden
        else if($foundVersion!=FTM_VERSION) {
            
            
            // Template auslesen
            $rootTemplate = $this->sysTemplateRepository->findOneRootTemplateByPidAndVersion($pid, $foundVersion);
            
            
            // Pruefen ob es ein Template gibt
            if($rootTemplate instanceof Tx_Ftm_Domain_Model_SysTemplate) {
                    
                $rootTemplate->setTitle("FTM ".FTM_VERSION." - Root-Template (Dont change this name!)");
                //$sysTemplateData = $this->updateTypoScript($foundVersion, FTM_VERSION, $foundRow);
            
                // Aenderungen speichern
                $this->sysTemplateRepository->update($rootTemplate);
                          
                // und persistieren
                $this->persistenceManager->persistAll();
            
                
                return "updated";
            }
            
        }
                
        return "alreadyExist";
    }
    
    /**
     * Setzt das fileadmin-Verzeichnis
     *
     * @author     Thomas Deuling <typo3@coding.ms>
     * @param      integer $pid Page-ID des Templates
     * @param      string $fileadminDir fileadmin-Verzeichnis des Templates
     * @since      22.11.2013
     */
    public function setFileadminDir($pid, $fileadminDir) {
        
        
        // Template auslesen
        $rootTemplate = $this->sysTemplateRepository->findOneRootTemplateByPidAndVersion($pid, FTM_VERSION);
        
        
        // Pruefen ob es ein Template gibt
        if($rootTemplate instanceof Tx_Ftm_Domain_Model_SysTemplate) {
            
            /**
             * @TODO: pruefen ob es das Verzeichnis wirklich gibt
             */
            
            
            /**
             * @ToDo: Hier muss auch geprueft werden ob schon TS/Konstanten enthalten sind
             * wenn ja muss versucht werden diese zu erhalten!
             */
            
            $relPath = "fileadmin/".$fileadminDir."/template/ts/";
            $absPath = t3lib_div::getFileAbsFileName($relPath);
            $setupTsFile       = "setup.ts";
            $setupCustomTsFile = "setupCustom.ts";
            $constantsTsFile       = "constants.ts";
            $constantsCustomTsFile = "constantsCustom.ts";
            
            
            // Setup erstellen 
            $setup = "### FTM-START ###\n";
            $setup.= "### Don't change this includes!\n";
            $setup.= "### Please use the setupCustom.ts for adding own TypoScript.\n";
            $setup.= "<INCLUDE_TYPOSCRIPT: source=\"FILE:".$relPath.$setupTsFile."\">\n";
            $setup.= "<INCLUDE_TYPOSCRIPT: source=\"FILE:".$relPath.$setupCustomTsFile."\">\n";
            $setup.= "### FTM-END ###\n";
            $rootTemplate->setConfig($setup);
            
            // Constants erstellen
            $constants = "### FTM-START ###\n";
            $constants.= "### Don't change this includes!\n";
            $constants.= "### Please use the constantsCustom.ts for adding own constants.\n";
            $constants.= "<INCLUDE_TYPOSCRIPT: source=\"FILE:".$relPath.$constantsTsFile."\">\n";
            $constants.= "<INCLUDE_TYPOSCRIPT: source=\"FILE:".$relPath.$constantsCustomTsFile."\">\n";
            $constants.= "### FTM-END ###\n";
            $rootTemplate->setConstants($constants);
         
         
            // Aenderungen speichern
            $this->sysTemplateRepository->update($rootTemplate);
                      
            // und persistieren
            $this->persistenceManager->persistAll();
            
            
            
            $messagesOk = "";
            $messagesError = "";
            
            
            // TypoScript Dateien erstellen,
            // falls noch nicht vorhanden
            if(!file_exists($absPath.$setupTsFile)) {
                if(!file_put_contents($absPath.$setupTsFile, "")) {
                    $messagesOk.= $setupTsFile." wurde erstellt!<br/>\n";
                    chmod($absPath.$setupTsFile, 0777);
                }
                else {
                    $messagesError.= $absPath.$setupTsFile." konnte nicht erstellt werden!<br/>\n";
                }
            }
            if(!file_exists($absPath.$setupCustomTsFile)) {
                if(!file_put_contents($absPath.$setupCustomTsFile, "")) {
                    $messagesOk.= $setupCustomTsFile." wurde erstellt!<br/>\n";
                    chmod($absPath.$setupCustomTsFile, 0777);
                }
                else {
                    $messagesError.= $absPath.$setupCustomTsFile." konnte nicht erstellt werden!<br/>\n";
                }
            }
            if(!file_exists($absPath.$constantsTsFile)) {
                if(!file_put_contents($absPath.$constantsTsFile, "")) {
                    $messagesOk.= $constantsTsFile." wurde erstellt!<br/>\n";
                    chmod($absPath.$constantsTsFile, 0777);
                }
                else {
                    $messagesError.= $absPath.$constantsTsFile." konnte nicht erstellt werden!<br/>\n";
                }
            }
            if(!file_exists($absPath.$constantsCustomTsFile)) {
                if(!file_put_contents($absPath.$constantsCustomTsFile, "")) {
                    $messagesOk.= $constantsCustomTsFile." wurde erstellt!<br/>\n";
                    chmod($absPath.$constantsCustomTsFile, 0777);
                }
                else {
                    $messagesError.= $absPath.$constantsCustomTsFile." konnte nicht erstellt werden!<br/>\n";
                }
            }
            
            return array('ok'=>$messagesOk, 'error'=>$messagesError);
        }
        
         return array();
    }

    
}

?>
