<?php
/***************************************************************
 *  Copyright notice
 *
 *  (c) 2012 Thomas Deuling <typo3@coding.ms>, coding.ms
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * Template-Verzeichnis Funktionen
 * Sorgt z.B. dafuer, das die Template-Verzeichnisstruktur
 * immer aktuell vorhanden ist
 *
 * @package ftm
 * @subpackage Service
 * 
 * @author Thomas Deuling <typo3@coding.ms>
 * @since 1.0.0
 */
class Tx_Ftm_Service_TemplateDirectory {
    

    /**
     * Benoetigte Verzeichnis Struktur
     * @var array
     * @since 1.0.0
     */
    public static $directories = array(
        'template'          => 'Hier liegt das gesamte Template',
        'template/css'      => 'Hier liegt generiertes CSS/LESS',
        'template/fonts'    => 'Hier liegen die verwendeten Schriftarten',
        'template/less'     => 'Hier liegt generiertes CSS/LESS',
        'template/ts'       => 'Hier liegt generiertes TS (config/setup)',
        'template/img'      => 'Hier liegen alle Template-Bilder',
        'template/img/icon' => 'Hier liegen alle Template-Icons',
        'template/js'       => 'Hier liegt das gesamte JavaScript',
        'template/fluid'    => 'Hier liegen alle allgemeinen Fluid-Dateien',
        'template/fluid/templates' => 'Hier liegen alle Fluid-Templates',
        'template/fluid/partials'  => 'Hier liegen alle Fluid-Partials',
        'template/fluid/layouts'   => 'Hier liegen alle Fluid-Layouts',
        'template/ext'      => 'Hier liegen alle Extension-Dateien',
        'content'           => 'Hier liegt der Content des Templates',
        'content/downloads' => 'Hier liegt die Downloads des Templates',
        'content/teaser'    => 'Hier liegt die Teaser-Bilder des Templates',
        'backup'            => 'Hier liegen Backup-Dateien der Templates',
    );
    
    /**
     * @ToDo: auch das 0_lessBasics etc erstellen und die Dateien reinkopieren
     */
    
         
    /**
     * Prueft die Template Verzeichnisstruktur
     * 
     * @author     Thomas Deuling <typo3@coding.ms>
     * @param      string Verzeichnis-Name im fileamin
     * @return     mixed true wenn alle Verzeichnisse vorhanden sind, ansonsten ein Array mit den vermissten Verzeichnissen
     * @since      1.0.0
     */
    public static function checkDirectories($fileadminPath) {
        
        $success = true;
        $missingDirectories = array();
        
        
        // Zuerst pruefen ob es das Projekt-Verzeichnis gibt
        $relPath = "fileadmin/".$fileadminPath;
        $absPath = t3lib_div::getFileAbsFileName($relPath);
        if(!is_dir($absPath)) {
            $success = false;
            $missingDirectories[$directory] = $description;
        }
        
        
        // Dann alle anderen Verzeichnisse pruefen 
        if(!empty(self::$directories) && $success) {
            foreach(self::$directories as $directory => $description) {
                
                $relPath = "fileadmin/".$fileadminPath."/".$directory;
                $absPath = t3lib_div::getFileAbsFileName($relPath);
                                
                if(!is_dir($absPath)) {
                    $success = false;
                    $missingDirectories[$directory] = $description;
                }
                
            }
        }
        
        if($success) {
            return true;
        }
        else {
            return $missingDirectories;
        }
    }
    
         
    /**
     * Erstellt die Template Verzeichnisstruktur
     * 
     * @author     Thomas Deuling <typo3@coding.ms>
     * @param      string Verzeichnis-Name im fileamin
     * @return     mixed true wenn alle Verzeichnisse vorhanden sind bzw. erstellt wurden, ansonsten ein Array mit den vermissten/nicht erstellten Verzeichnissen
     * @since      1.0.0
     */
    public static function createDirectories($fileadminPath) {
        
        $success = true;
        $missingDirectories = array();
        
        
        // Zuerst pruefen ob es das Projekt-Verzeichnis gibt
        $relPath = "fileadmin/".$fileadminPath;
        $absPath = t3lib_div::getFileAbsFileName($relPath);
        if(!is_dir($absPath)) {
            if(!mkdir($absPath)) {
                $success = false;
                $missingDirectories[$directory] = $description;
            }
            else {
                chmod($absPath, 0777);
            }
        }
        
        
        // Dann alle anderen Verzeichnisse pruefen 
        if(!empty(self::$directories) && $success) {
            foreach(self::$directories as $directory => $description) {
                
                $relPath = "fileadmin/".$fileadminPath."/".$directory;
                $absPath = t3lib_div::getFileAbsFileName($relPath);
                                
                if(!is_dir($absPath)) {
                    if(!mkdir($absPath)) {
                        $success = false;
                        $missingDirectories[$directory] = $description;
                    }
                    else {
                        chmod($absPath, 0777);
                    }
                }
                
            }
        }
        
        if($success) {
            return true;
        }
        else {
            return $missingDirectories;
        }
    }
    
    
}

?>
